<?php

defined('ABSPATH') or die;

/*
 *
 * Require the framework class before doing anything else, so we can use the defined urls and dirs
 *
 */
require_once( dirname( __FILE__ ) . '/options/options.php' );

/*
 * 
 * Add support tab
 *
 */
if ( ! defined('MTS_THEME_WHITE_LABEL') || ! MTS_THEME_WHITE_LABEL ) {
	require_once( dirname( __FILE__ ) . '/options/support.php' );
	$mts_options_tab_support = MTS_Options_Tab_Support::get_instance();
}

/*
 *
 * Custom function for filtering the sections array given by theme, good for child themes to override or add to the sections.
 * Simply include this function in the child themes functions.php file.
 *
 * NOTE: the defined constansts for urls, and dir will NOT be available at this point in a child theme, so you must use
 * get_template_directory_uri() if you want to use any of the built in icons
 *
 */
function add_another_section($sections){

	//$sections = array();
	$sections[] = array(
		'title' => __('A Section added by hook', 'lifestyle' ),
		'desc' => '<p class="description">' . __('This is a section created by adding a filter to the sections array, great to allow child themes, to add/remove sections from the options.', 'lifestyle' ) . '</p>',
		//all the glyphicons are included in the options folder, so you can hook into them, or link to your own custom ones.
		//You dont have to though, leave it blank for default.
		'icon' => trailingslashit(get_template_directory_uri()).'options/img/glyphicons/glyphicons_062_attach.png',
		//Lets leave this as a blank section, no options just some intro text set above.
		'fields' => array()
	);

	return $sections;

}//function
//add_filter('nhp-opts-sections-twenty_eleven', 'add_another_section');


/*
 *
 * Custom function for filtering the args array given by theme, good for child themes to override or add to the args array.
 *
 */
function change_framework_args($args){

	//$args['dev_mode'] = false;

	return $args;

}//function
//add_filter('nhp-opts-args-twenty_eleven', 'change_framework_args');

/*
 * This is the meat of creating the optons page
 *
 * Override some of the default values, uncomment the args and change the values
 * - no $args are required, but there there to be over ridden if needed.
 *
 *
 */

function setup_framework_options(){
	$args = array();

	//Set it to dev mode to view the class settings/info in the form - default is false
	$args['dev_mode'] = false;
	//Remove the default stylesheet? make sure you enqueue another one all the page will look whack!
	//$args['stylesheet_override'] = true;

	//Add HTML before the form
	//$args['intro_text'] = __('<p>This is the HTML which can be displayed before the form, it isnt required, but more info is always better. Anything goes in terms of markup here, any HTML.</p>', 'lifestyle' );

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Setup custom links in the footer for share icons
		$args['share_icons']['twitter'] = array(
			'link' => 'http://twitter.com/mythemeshopteam',
			'title' => __( 'Follow Us on Twitter', 'lifestyle' ),
			'img' => 'fa fa-twitter-square'
		);
		$args['share_icons']['facebook'] = array(
			'link' => 'http://www.facebook.com/mythemeshop',
			'title' => __( 'Like us on Facebook', 'lifestyle' ),
			'img' => 'fa fa-facebook-square'
		);
	}

	//Choose to disable the import/export feature
	//$args['show_import_export'] = false;

	//Choose a custom option name for your theme options, the default is the theme name in lowercase with spaces replaced by underscores
	$args['opt_name'] = MTS_THEME_NAME;

	//Custom menu icon
	//$args['menu_icon'] = '';

	//Custom menu title for options page - default is "Options"
	$args['menu_title'] = __('Theme Options', 'lifestyle' );

	//Custom Page Title for options page - default is "Options"
	$args['page_title'] = __('Theme Options', 'lifestyle' );

	//Custom page slug for options page (wp-admin/themes.php?page=***) - default is "nhp_theme_options"
	$args['page_slug'] = 'theme_options';

	//Custom page capability - default is set to "manage_options"
	//$args['page_cap'] = 'manage_options';

	//page type - "menu" (adds a top menu section) or "submenu" (adds a submenu) - default is set to "menu"
	//$args['page_type'] = 'submenu';

	//parent menu - default is set to "themes.php" (Appearance)
	//the list of available parent menus is available here: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
	//$args['page_parent'] = 'themes.php';

	//custom page location - default 100 - must be unique or will override other items
	$args['page_position'] = 62;

	//Custom page icon class (used to override the page icon next to heading)
	//$args['page_icon'] = 'icon-themes';

	if ( ! MTS_THEME_WHITE_LABEL ) {
		//Set ANY custom page help tabs - displayed using the new help tab API, show in order of definition
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-1',
			'title' => __('Support', 'lifestyle' ),
			'content' => '<p>' . sprintf( __('If you are facing any problem with our theme or theme option panel, head over to our %s.', 'lifestyle' ), '<a href="http://community.mythemeshop.com/">'. __( 'Support Forums', 'lifestyle' ) . '</a>' ) . '</p>'
		);
		$args['help_tabs'][] = array(
			'id' => 'nhp-opts-2',
			'title' => __('Earn Money', 'lifestyle' ),
			'content' => '<p>' . sprintf( __('Earn 70%% commision on every sale by refering your friends and readers. Join our %s.', 'lifestyle' ), '<a href="http://mythemeshop.com/affiliate-program/">' . __( 'Affiliate Program', 'lifestyle' ) . '</a>' ) . '</p>'
		);
	}

	//Set the Help Sidebar for the options page - no sidebar by default
	//$args['help_sidebar'] = __('<p>This is the sidebar content, HTML is allowed.</p>', 'lifestyle' );

	$mts_patterns = array(
		'nobg' => array('img' => NHP_OPTIONS_URL.'img/patterns/nobg.png'),
		'pattern0' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern0.png'),
		'pattern1' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern1.png'),
		'pattern2' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern2.png'),
		'pattern3' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern3.png'),
		'pattern4' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern4.png'),
		'pattern5' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern5.png'),
		'pattern6' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern6.png'),
		'pattern7' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern7.png'),
		'pattern8' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern8.png'),
		'pattern9' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern9.png'),
		'pattern10' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern10.png'),
		'pattern11' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern11.png'),
		'pattern12' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern12.png'),
		'pattern13' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern13.png'),
		'pattern14' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern14.png'),
		'pattern15' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern15.png'),
		'pattern16' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern16.png'),
		'pattern17' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern17.png'),
		'pattern18' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern18.png'),
		'pattern19' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern19.png'),
		'pattern20' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern20.png'),
		'pattern21' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern21.png'),
		'pattern22' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern22.png'),
		'pattern23' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern23.png'),
		'pattern24' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern24.png'),
		'pattern25' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern25.png'),
		'pattern26' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern26.png'),
		'pattern27' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern27.png'),
		'pattern28' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern28.png'),
		'pattern29' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern29.png'),
		'pattern30' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern30.png'),
		'pattern31' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern31.png'),
		'pattern32' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern32.png'),
		'pattern33' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern33.png'),
		'pattern34' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern34.png'),
		'pattern35' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern35.png'),
		'pattern36' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern36.png'),
		'pattern37' => array('img' => NHP_OPTIONS_URL.'img/patterns/pattern37.png'),
		'hbg' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg.png'),
		'hbg2' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg2.png'),
		'hbg3' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg3.png'),
		'hbg4' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg4.png'),
		'hbg5' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg5.png'),
		'hbg6' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg6.png'),
		'hbg7' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg7.png'),
		'hbg8' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg8.png'),
		'hbg9' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg9.png'),
		'hbg10' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg10.png'),
		'hbg11' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg11.png'),
		'hbg12' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg12.png'),
		'hbg13' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg13.png'),
		'hbg14' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg14.png'),
		'hbg15' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg15.png'),
		'hbg16' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg16.png'),
		'hbg17' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg17.png'),
		'hbg18' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg18.png'),
		'hbg19' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg19.png'),
		'hbg20' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg20.png'),
		'hbg21' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg21.png'),
		'hbg22' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg22.png'),
		'hbg23' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg23.png'),
		'hbg24' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg24.png'),
		'hbg25' => array('img' => NHP_OPTIONS_URL.'img/patterns/hbg25.png')
	);

	$sections = array();

	$sections[] = array(
		'icon' => 'fa fa-cogs',
		'title' => __('General Settings', 'lifestyle' ),
		'desc' => '<p class="description">' . __('This tab contains common setting options which will be applied to the whole theme.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_logo',
				'type' => 'upload',
				'title' => __('Logo Image', 'lifestyle' ),
				'sub_desc' => __('Upload your logo using the Upload Button or insert image URL.', 'lifestyle' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_favicon',
				'type' => 'upload',
				'title' => __('Favicon', 'lifestyle' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s favicon.', 'lifestyle' ), '<strong>32 x 32 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_touch_icon',
				'type' => 'upload',
				'title' => __('Touch icon', 'lifestyle' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s touch icon for iOS 2.0+ and Android 2.1+ devices.', 'lifestyle' ), '<strong>152 x 152 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_metro_icon',
				'type' => 'upload',
				'title' => __('Metro icon', 'lifestyle' ),
				'sub_desc' => sprintf( __('Upload a %s image that will represent your website\'s IE 10 Metro tile icon.', 'lifestyle' ), '<strong>144 x 144 px</strong>' ),
				'return' => 'id'
			),
			array(
				'id' => 'mts_twitter_username',
				'type' => 'text',
				'title' => __('Twitter Username', 'lifestyle' ),
				'sub_desc' => __('Enter your Username here.', 'lifestyle' ),
			),
			array(
				'id' => 'mts_feedburner',
				'type' => 'text',
				'title' => __('FeedBurner URL', 'lifestyle' ),
				'sub_desc' => sprintf( __('Enter your FeedBurner\'s URL here, ex: %s and your main feed (http://example.com/feed) will get redirected to the FeedBurner ID entered here.)', 'lifestyle' ), '<strong>http://feeds.feedburner.com/mythemeshop</strong>' ),
				'validate' => 'url'
			),
			array(
				'id' => 'mts_header_code',
				'type' => 'textarea',
				'title' => __('Header Code', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'lifestyle' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_analytics_code',
				'type' => 'textarea',
				'title' => __('Footer Code', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'lifestyle' ), array( 'strong' => array() ) )
			),
			array(
				'id' => 'mts_pagenavigation_type',
				'type' => 'radio',
				'title' => __('Pagination Type', 'lifestyle' ),
				'sub_desc' => __('Select pagination type.', 'lifestyle' ),
				'options' => array(
					'0'=> __('Default (Next / Previous)', 'lifestyle' ),
					'1' => __('Numbered (1 2 3 4...)', 'lifestyle' ),
					'2' => __( 'AJAX (Load More Button)', 'lifestyle' ),
					'3' => __( 'AJAX (Auto Infinite Scroll)', 'lifestyle' )
				),
				'std' => '1'
			),
			array(
				'id' => 'mts_ajax_search',
				'type' => 'button_set',
				'title' => __('AJAX Quick search', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Enable or disable search results appearing instantly below the search form', 'lifestyle' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_responsive',
				'type' => 'button_set',
				'title' => __('Responsiveness', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('MyThemeShop themes are responsive, which means they adapt to tablet and mobile devices, ensuring that your content is always displayed beautifully no matter what device visitors are using. Enable or disable responsiveness using this option.', 'lifestyle' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_rtl',
				'type' => 'button_set',
				'title' => __('Right To Left Language Support', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Enable this option for right-to-left sites.', 'lifestyle' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_shop_products',
				'type' => 'text',
				'title' => __('No. of Products', 'lifestyle' ),
				'sub_desc' => __('Enter the total number of products which you want to show on shop page (WooCommerce plugin must be enabled).', 'lifestyle' ),
				'validate' => 'numeric',
				'std' => '9',
				'class' => 'small-text'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bolt',
		'title' => __('Performance', 'lifestyle' ),
		'desc' => '<p class="description">' . __('This tab contains performance-related options which can help speed up your website.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_prefetching',
				'type' => 'button_set',
				'title' => __('Prefetching', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Enable or disable prefetching. If user is on homepage, then single page will load faster and if user is on single page, homepage will load faster in modern browsers.', 'lifestyle' ),
				'std' => '0'
			),
			array(
				'id' => 'mts_lazy_load',
				'type' => 'button_set_hide_below',
				'title' => __('Theme\'s Lazy Loading', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Delay loading of images outside of viewport, until user scrolls to them.', 'lifestyle' ),
				'std' => '0',
				'args' => array('hide' => 2)
				),
				array(
					'id' => 'mts_lazy_load_thumbs',
					'type' => 'button_set',
					'title' => __('Lazy load featured images', 'lifestyle' ),
					'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
					'sub_desc' => __('Enable or disable Lazy load of featured images across site.', 'lifestyle' ),
					'std' => '0'
				),
				array(
					'id' => 'mts_lazy_load_content',
					'type' => 'button_set',
					'title' => __('Lazy load post content images', 'lifestyle' ),
					'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
					'sub_desc' => __('Enable or disable Lazy load of images inside post/page content.', 'lifestyle' ),
					'std' => '0'
			),
			array(
				'id' => 'mts_async_js',
				'type' => 'button_set',
				'title' => __('Async JavaScript', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => sprintf( __('Add %s attribute to script tags to improve page download speed.', 'lifestyle' ), '<code>async</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_remove_ver_params',
				'type' => 'button_set',
				'title' => __('Remove ver parameters', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => sprintf( __('Remove %s parameter from CSS and JS file calls. It may improve speed in some browsers which do not cache files having the parameter.', 'lifestyle' ), '<code>ver</code>' ),
				'std' => '1',
			),
			array(
				'id' => 'mts_optimize_wc',
				'type' => 'button_set',
				'title' => __('Optimize WooCommerce scripts', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Load WooCommerce scripts and styles only on WooCommerce pages (WooCommerce plugin must be enabled).', 'lifestyle' ),
				'std' => '1'
			),
			'cache_message' => array(
				'id' => 'mts_cache_message',
				'type' => 'info',
				'title' => __('Use Cache', 'lifestyle' ),
				// Translators: %1$s = popup link to W3 Total Cache, %2$s = popup link to WP Super Cache
				'desc' => sprintf(
					__('A cache plugin can increase page download speed dramatically. We recommend using %1$s or %2$s.', 'lifestyle' ),
					'<a href="https://community.mythemeshop.com/tutorials/article/8-make-your-website-load-faster-using-w3-total-cache-plugin/" target="_blank" title="W3 Total Cache">W3 Total Cache</a>',
					'<a href="'.admin_url( 'plugin-install.php?tab=plugin-information&plugin=wp-super-cache&TB_iframe=true&width=772&height=574' ).'" class="thickbox" title="WP Super Cache">WP Super Cache</a>'
				),
			),
		)
	);

	// Hide cache message on multisite or if a chache plugin is active already
	if ( is_multisite() || strstr( join( ';', get_option( 'active_plugins' ) ), 'cache' ) ) {
		unset( $sections[1]['fields']['cache_message'] );
	}

	$sections[] = array(
		'icon' => 'fa fa-adjust',
		'title' => __('Styling Options', 'lifestyle' ),
		'desc' => '<p class="description">' . __('Control the visual appearance of your theme, such as colors, layout and patterns, from here.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_color_scheme',
				'type' => 'color',
				'title' => __('Color Scheme', 'lifestyle' ),
				'sub_desc' => __('The theme comes with unlimited color schemes for your theme\'s styling.', 'lifestyle' ),
				'std' => '#d87ca1'
			),
			array(
				'id' => 'mts_layout',
				'type' => 'radio_img',
				'title' => __('Layout Style', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Choose the <strong>default sidebar position</strong> for your site. The position of the sidebar for individual posts can be set in the post editor.', 'lifestyle' ), array( 'strong' => array() ) ),
				'options' => array(
					'cslayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/cs.png'),
					'sclayout' => array('img' => NHP_OPTIONS_URL.'img/layouts/sc.png')
				),
				'std' => 'cslayout'
			),
			array(
				'id' => 'mts_background',
				'type' => 'background',
				'title' => __('Site Background', 'lifestyle' ),
				'sub_desc' => __('Set background color, pattern and image from here.', 'lifestyle' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_custom_css',
				'type' => 'textarea',
				'title' => __('Custom CSS', 'lifestyle' ),
				'sub_desc' => __('You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'lifestyle' )
			),
			array(
				'id' => 'mts_page_loader',
				'type' => 'button_set',
				'title' => __('Page Loader', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Show the Animated page loader before page load.', 'lifestyle' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_lightbox',
				'type' => 'button_set',
				'title' => __('Lightbox', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('A lightbox is a stylized pop-up that allows your visitors to view larger versions of images without leaving the current page. You can enable or disable the lightbox here.', 'lifestyle' ),
				'std' => '0'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-credit-card',
		'title' => __('Header', 'lifestyle' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of header section.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_header_layout',
				'type' => 'radio_img',
				'title' => __('Header Style', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Choose the <strong>header layout</strong> for your site.', 'lifestyle' ), array( 'strong' => array() ) ),
				'options' => array(
					'header-2' => array('img' => NHP_OPTIONS_URL.'img/layouts/header-2.png'),
					'default' => array('img' => NHP_OPTIONS_URL.'img/layouts/header-1.png'),
					'header-3' => array('img' => NHP_OPTIONS_URL.'img/layouts/header-3.png')
				),
				'std' => 'header-2'
			),
			array(
				'id' => 'mts_header_background',
				'type' => 'background',
				'title' => __('Header Background', 'lifestyle' ),
				'sub_desc' => __('Set header background color, pattern and image from here.', 'lifestyle' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#ffffff',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_sticky_nav',
				'type' => 'button_set',
				'title' => __('Floating Navigation Menu', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'lifestyle' ), '<strong>' . __('Floating Navigation Menu', 'lifestyle' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_social',
				'title' => __('Header Social Icons', 'lifestyle'), 
				'sub_desc' => __( 'Add Social Media icons in the Header.', 'lifestyle' ),
				'type' => 'group',
				'groupname' => __('Header Icon', 'lifestyle'), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_header_icon_title',
							'type' => 'text',
							'title' => __('Title', 'lifestyle'), 
							),
						array(
							'id' => 'mts_header_icon',
							'type' => 'icon_select',
							'title' => __('Icon', 'lifestyle')
							),
						array(
							'id' => 'mts_header_icon_link',
							'type' => 'text',
							'title' => __('URL', 'lifestyle'), 
							),
						array(
							'id' => 'mts_header_icon_bgcolor',
							'type' => 'color',
							'title' => __('Background Color', 'lifestyle'),
							'std' => '#333333'
							),
						),
				'std' => array(
					'facebook' => array(
						'group_title' => 'Facebook',
						'group_sort' => '1',
						'mts_header_icon_title' => 'Facebook',
						'mts_header_icon' => 'facebook',
						'mts_header_icon_link' => '#',
						'mts_header_icon_bgcolor' => '#337ab7'
					),
					'twitter' => array(
						'group_title' => 'Pinterest',
						'group_sort' => '2',
						'mts_header_icon_title' => 'Pinterest',
						'mts_header_icon' => 'pinterest',
						'mts_header_icon_link' => '#',
						'mts_header_icon_bgcolor' => '#e85657'
					),
					'youtube' => array(
						'group_title' => 'YouTube',
						'group_sort' => '3',
						'mts_header_icon_title' => 'YouTube',
						'mts_header_icon' => 'youtube-play',
						'mts_header_icon_link' => '#',
						'mts_header_icon_bgcolor' => '#c9322b'
					)
				)
			),
			array(
				'id' => 'mts_show_primary_nav',
				'type' => 'button_set',
				'title' => __('Show Menu', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => sprintf( __('Use this button to enable %s.', 'lifestyle' ), '<strong>' . __( 'Navigation Menu', 'lifestyle' ) . '</strong>' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_section2',
				'type' => 'button_set',
				'title' => __('Show Logo', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide the <strong>Logo</strong> completely.', 'lifestyle' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_header_search',
				'type' => 'button_set',
				'title' => __('Show Header Search Form', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => wp_kses( __('Use this button to Show or Hide the <strong>Header Search Form</strong> completely.', 'lifestyle' ), array( 'strong' => array() ) ),
				'std' => '1'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-table',
		'title' => __('Footer', 'lifestyle' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of Footer section.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_first_footer',
				'type' => 'button_set_hide_below',
				'title' => __('Footer', 'lifestyle' ),
				'sub_desc' => __('Enable or disable footer with this option.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '0',
				'args' => array('hide' => 2)
				),
				array(
					'id' => 'mts_footer_background',
					'type' => 'background',
					'title' => __('Footer Background', 'lifestyle' ),
					'sub_desc' => __('Set footer background color, pattern and image from here.', 'lifestyle' ),
					'options' => array(
						'color'		 => '',
						'image_pattern' => $mts_patterns,
						'image_upload'  => '',
						'repeat'		=> array(),
						'attachment'	=> array(),
						'position'	=> array(),
						'size'		=> array(),
						'gradient'	=> '',
						'parallax'	=> array(),
					),
					'std' => array(
						'color'		 => '#f2f2f2',
						'use'		 => 'pattern',
						'image_pattern' => 'nobg',
						'image_upload'  => '',
						'repeat'		=> 'repeat',
						'attachment'	=> 'scroll',
						'position'	=> 'left top',
						'size'		=> 'cover',
						'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
						'parallax'	=> '0',
					)
				),
				array(
					'id' => 'mts_first_footer_num',
					'type' => 'button_set',
					'class' => 'green',
					'title' => __('Footer Layout', 'lifestyle' ),
					'sub_desc' => wp_kses( __('Choose the number of widget areas in the <strong>footer</strong>', 'lifestyle' ), array( 'strong' => array() ) ),
					'options' => array(
						'4' => __( '4 Widgets', 'lifestyle' ),
						'5' => __( '5 Widgets', 'lifestyle' ),
					),
					'std' => '5'
			),
			array(
				'id' => 'mts_copyrights_background',
				'type' => 'background',
				'title' => __('Copyrights Background', 'lifestyle' ),
				'sub_desc' => __('Set copyrights background color, pattern and image from here.', 'lifestyle' ),
				'options' => array(
					'color'		 => '',
					'image_pattern' => $mts_patterns,
					'image_upload'  => '',
					'repeat'		=> array(),
					'attachment'	=> array(),
					'position'	=> array(),
					'size'		=> array(),
					'gradient'	=> '',
					'parallax'	=> array(),
				),
				'std' => array(
					'color'		 => '#e6e6e6',
					'use'		 => 'pattern',
					'image_pattern' => 'nobg',
					'image_upload'  => '',
					'repeat'		=> 'repeat',
					'attachment'	=> 'scroll',
					'position'	=> 'left top',
					'size'		=> 'cover',
					'gradient'	=> array('from' => '#ffffff', 'to' => '#000000', 'direction' => 'horizontal' ),
					'parallax'	=> '0',
				)
			),
			array(
				'id' => 'mts_copyrights',
				'type' => 'textarea',
				'title' => __('Copyrights Text', 'lifestyle' ),
				'sub_desc' => __( 'You can change or remove our link from footer and use your own custom text.', 'lifestyle' ) . ( MTS_THEME_WHITE_LABEL ? '' : wp_kses( __('(You can also use your affiliate link to <strong>earn 70% of sales</strong>. Ex: <a href="https://mythemeshop.com/go/aff/aff" target="_blank">https://mythemeshop.com/?ref=username</a>)', 'lifestyle' ), array( 'strong' => array(), 'a' => array( 'href' => array(), 'target' => array() ) ) ) ),
				'std' => MTS_THEME_WHITE_LABEL ? null : sprintf( __( 'Theme by %s', 'lifestyle' ), '<a href="http://mythemeshop.com/">MyThemeShop</a>' )
			),
		)
	);
	$sections[] = array(
		'icon' => '',
		'title' => __('HomePage', 'lifestyle' ),
		'desc' => '<p class="description">' . __('From here, you can control the elements of the homepage.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_featured_categories',
				'type' => 'group',
				'title'	 => __('Featured Categories', 'lifestyle' ),
				'sub_desc'  => __('Select categories appearing on the homepage.', 'lifestyle' ),
				'groupname' => __('Section', 'lifestyle' ), // Group name
				'subfields' =>
					array(
						array(
							'id' => 'mts_featured_category',
							'type' => 'cats_select',
							'title' => __('Category', 'lifestyle' ),
							'sub_desc' => __('Select a category or the latest posts for this section', 'lifestyle' ),
							'std' => 'latest',
							'args' => array('include_latest' => 1, 'hide_empty' => 0),
						),
						array(
							'id' => 'mts_featured_category_layout',
							'type' => 'select_hide_below',
							'title' => __('Posts Layout', 'lifestyle'),
							'sub_desc' => __('Select posts layout for this section.', 'lifestyle'),
							'options' => array(												
								'layout-1' => array('name' => __('Layout 1', 'lifestyle'), 'allow' => 'false'),
								'layout-2' => array('name' => __('Layout 2', 'lifestyle'), 'allow' => 'true'),
								'layout-3' => array('name' => __('Layout 3', 'lifestyle'), 'allow' => 'false')
							),//Must provide key => value(array) pairs for select options
							'std' => 'layout-2',
							'args' => array('hide' => 1)
						),
						array(
							'id' => 'mts_featured_text_color',
							'type' => 'color',
							'selected' => 'layout-2',
							'title' => __('Text Color Scheme', 'lifestyle' ),
							'sub_desc' => __('Set text color for this post section.', 'lifestyle' ),
							'std' => '#333333'
						),
						array(
							'id' => 'mts_featured_bg_color',
							'type' => 'color',
							'title' => __('Background Color Scheme', 'lifestyle' ),
							'sub_desc' => __('Set background color for this post section.', 'lifestyle' ),
							'std' => '#ffffff'
						),
						array(
							'id' => 'mts_featured_category_postsnum',
							'type' => 'text',
							'class' => 'small-text',
							'title' => __('Number of posts', 'lifestyle' ),
							'sub_desc' => __('Enter the number of posts to show in this section.', 'lifestyle' ),
							'std' => '4',
							'args' => array('type' => 'number')
						),
						array(
							'id' => 'mts_home_meta_info_enable',
							'type' => 'multi_checkbox',
							'title' => __('Layout Post Meta Info', 'lifestyle' ),
							'sub_desc'  => __('Show or Hide Post Meta Info on Homepage article layout.', 'lifestyle' ),
							'options' => array(
								'author' => __('Author Name', 'lifestyle' ),
								'comment' => __('Comments', 'lifestyle' ),
								'time'=> __('Time/Date', 'lifestyle' ),
								'category'=>__('Category', 'lifestyle' )
							),
							'std' => array(
								'author'=> '1',
								'comment'=> '1',
								'time'=> '0',
								'category'=>'0'
							)
						),
				),
				'std' => array(
					'1' => array(
						'group_title' => '',
						'group_sort' => '1',
						'mts_featured_category' => 'latest',
						'mts_featured_category_layout' => 'layout-2',
						'mts_featured_category_postsnum' => get_option('posts_per_page'),
						'mts_featured_bg_color' => '#ffffff'
					)
				)
			),
			array(
				'id' => 'mts_animation',
				'type' => 'button_set',
				'title' => __('Post Image Animation', 'lifestyle' ),
				'sub_desc' => __('Enable or disable post image animation.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '1'
			),
			array(
				'id'	 => 'mts_home_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('Post Meta Info for Archive, Search and other pages.', 'lifestyle' ),
				'sub_desc' => __('Organize how you want the post meta info to appear on the pages', 'lifestyle' ),
				'options'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'lifestyle' ),
						'comment'  => __('Comment Count', 'lifestyle' )
					),
					'disabled' => array(
						'date'	 => __('Date', 'lifestyle' ),
						'category' => __('Categories', 'lifestyle' )
					)
				),
				'std'  => array(
					'enabled'  => array(
						'author'   => __('Author Name', 'lifestyle' ),
						'comment'  => __('Comment Count', 'lifestyle' )
					),
					'disabled' => array(
						'date'	 => __('Date', 'lifestyle' ),
						'category' => __('Categories', 'lifestyle' )
					)
				)
			),
		)
	);
	$sections[] = array(
		'icon' => '',
		'title' => __('Home Social Icons', 'lifestyle'),
		'desc' => '<p class="description">' . __('Control settings related to Featured Slider.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_home_social_icons_section',
				'type' => 'button_set_hide_below',
				'title' => __('HomePage Social Icons Section', 'lifestyle' ),
				'sub_desc' => __('Enable or disable homepage social icons section with this option.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '1'
			),
			array(
				'id' => 'mts_home_social',
				'title' => __('Home Social Icons', 'lifestyle'), 
				'sub_desc' => __( 'Add Social Media icons on HomePage.', 'lifestyle' ),
				'type' => 'group',
				'groupname' => __('Social Icon', 'lifestyle'), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_home_social_title',
							'type' => 'text',
							'title' => __('Title', 'lifestyle')
							),
						array(
							'id' => 'mts_home_social_icon',
							'type' => 'icon_select',
							'title' => __('Icon', 'lifestyle')
							),
						array(
							'id' => 'mts_home_social_followers',
							'type' => 'text',
							'title' => __('Followers', 'lifestyle')
							),
						array(
							'id' => 'mts_home_social_bgcolor',
							'type' => 'color',
							'title' => __('Background Color', 'lifestyle'),
							'std' => '#fe5c74'
							),
						),
				'std' => array(
					'facebook' => array(
						'group_title' => 'Facebook',
						'group_sort' => '1',
						'mts_home_social_title' => 'Facebook',
						'mts_home_social_icon' => 'facebook',
						'mts_home_social_followers' => '4M Followers',
						'mts_home_social_bgcolor' => '#337ab7'
					),
					'pinterest' => array(
						'group_title' => 'Pinterest',
						'group_sort' => '2',
						'mts_home_social_title' => 'Pinterest',
						'mts_home_social_icon' => 'pinterest',
						'mts_home_social_followers' => '512.2k Followers',
						'mts_home_social_bgcolor' => '#ea5656'
					),
					'twitter' => array(
						'group_title' => 'Twitter',
						'group_sort' => '3',
						'mts_home_social_title' => 'Twitter',
						'mts_home_social_icon' => 'twitter',
						'mts_home_social_followers' => '3.2M Followers',
						'mts_home_social_bgcolor' => '#40bff5'
					),
				)
			),
			array(
				'id' => 'mts_home_social_icons_after_x_sections',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Show Social Icons after X sections', 'lifestyle' ),
				'sub_desc' => __('Enter the number where you want to show the home social icons. It will show after that section.', 'lifestyle' ),
				'std' => '1',
				'args' => array(
					'type' => 'number'
				)
			),
			
		),
	);
	$sections[] = array(
		'icon' => '',
		'title' => __('Lets Shop', 'lifestyle'),
		'desc' => '<p class="description">' . __('Control settings related to Let&apos;s Shop Section.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_shop_section',
				'type' => 'button_set_hide_below',
				'title' => __('Shop Section', 'lifestyle' ),
				'sub_desc' => __('Enable or disable shop section with this option.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '0',
				'args' => array('hide' => 5)
			),
			array(
				'id' => 'mts_shop_title',
				'type' => 'text',
				'title' => __('Main Title', 'lifestyle' ),
				'std' => __('Let&apos;s shop', 'lifestyle' )
			),
			array(
				'id' => 'mts_shop_image',
				'type' => 'upload',
				'title' => __('Shop Image', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Upload your images using the Upload Button or insert image URL. Recommended size: <strong>585x370 pixel</strong>.', 'lifestyle' ), array( 'strong' => array() ) ),
				'return' => 'url',
				'std' => get_template_directory_uri() . '/images/lets-shop.jpg'
			),
			array(
				'id' => 'mts_shop_description',
				'type' => 'textarea',
				'title' => __('Shop description', 'lifestyle' ),
				'std' => __('Vivamus eget urna eu odio rutrum placerat id volutpat nunc. Vivamus at facilisis mi. Etiam a erat pharetra mi tincidunt viverra ac a sem', 'lifestyle' )
			),
			array(
				'id' => 'mts_shop_subheading',
				'type' => 'text',
				'title' => __('Sub Heading', 'lifestyle' ),
				'std' => __('Best Selling', 'lifestyle' )
			),
			array(
				'id' => 'mts_shop_list',
				'title' => __('Shop Lists', 'lifestyle'),
				'sub_desc' => __( 'Add Lists in the Let&apos;s Shop Section.', 'lifestyle' ),
				'type' => 'group',
				'groupname' => __('List', 'lifestyle'), // Group name
				'subfields' => 
					array(
						array(
							'id' => 'mts_shop_list_title',
							'type' => 'text',
							'title' => __('Text', 'lifestyle')
							),
						array(
							'id' => 'mts_shop_list_icon',
							'type' => 'icon_select',
							'title' => __('Icon', 'lifestyle')
							),
						array(
							'id' => 'mts_shop_list_url',
							'type' => 'text',
							'title' => __('URL', 'lifestyle')
							)
						),
				'std' => array(
				)
			),
			array(
				'id' => 'mts_lets_shop_after_x_sections',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Show Lets Shop after X sections', 'lifestyle' ),
				'sub_desc' => __('Enter the number where you want to show the Lets Shop. It will show after that section.', 'lifestyle' ),
				'std' => '3',
				'args' => array(
					'type' => 'number'
				)
			),
		),
	);
	$sections[] = array(
		'icon' => '',
		'title' => __('Instagram Section', 'lifestyle'),
		'desc' => '<p class="description">' . __('Control settings Instagram Section.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_instagram',
				'type' => 'button_set_hide_below',
				'title' => __('Instagram Section', 'lifestyle' ),
				'sub_desc' => __('Enable or disable instagram feeds with this option.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '0',
				'args' => array('hide' => 3)
			),
			array(
				'id' => 'mts_instagram_title',
				'type' => 'text',
				'title' => __('Instagram Section Title', 'lifestyle' ),
				'sub_desc' => __('Enter your instagram title here.', 'lifestyle' ),
				'std' => 'Instagram'
			),
			array(
				'id' => 'mts_username',
				'type' => 'text',
				'title' => __('Instagram Username', 'lifestyle' ),
				'sub_desc' => __('Enter your instagram username here.', 'lifestyle' ),
				'std' => ''
			),
			array(
				'id' => 'mts_instagram_after_x_sections',
				'type' => 'text',
				'class' => 'small-text',
				'title' => __('Show Instagram Section after X sections', 'lifestyle' ),
				'sub_desc' => __('Enter the number where you want to show the Instagram Section. It will show after that section.', 'lifestyle' ),
				'std' => '5',
				'args' => array(
					'type' => 'number'
				)
			),
			array(
				'id' => 'mts_instagram_single',
				'type' => 'button_set_hide_below',
				'title' => __('Instagram Section on Single Page', 'lifestyle' ),
				'sub_desc' => __('Enable or disable instagram feeds on single page.', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'std' => '0'
			),
		),
	);
	$sections[] = array(
		'icon' => 'fa fa-file-text',
		'title' => __('Single Posts', 'lifestyle' ),
		'desc' => '<p class="description">' . __('From here, you can control the appearance and functionality of your single posts page.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id'	 => 'mts_single_post_layout',
				'type'	 => 'layout2',
				'title'	=> __('Single Post Layout', 'lifestyle' ),
				'sub_desc' => __('Customize the look of single posts', 'lifestyle' ),
				'options'  => array(
					'enabled'  => array(
						'content'   => array(
							'label' 	=> __('Post Content', 'lifestyle' ),
							'subfields'	=> array(

							)
						),
						'related'   => array(
							'label' 	=> __('Related Posts', 'lifestyle' ),
							'subfields'	=> array(
								array(
									'id' => 'mts_related_posts_title',
									'type' => 'text',
									'title' => __('Related Posts Title', 'lifestyle' ),
									'sub_desc' => __('Enter the related posts title.', 'lifestyle' ),
									'class' => 'medium',
									'std' => 'You may also like'
								),
								array(
									'id' => 'mts_related_posts_taxonomy',
									'type' => 'button_set',
									'title' => __('Related Posts Taxonomy', 'lifestyle' ) ,
									'options' => array(
										'tags' => __( 'Tags', 'lifestyle' ),
										'categories' => __( 'Categories', 'lifestyle' )
									) ,
									'class' => 'green',
									'sub_desc' => __('Related Posts based on tags or categories.', 'lifestyle' ) ,
									'std' => 'categories'
								),
								array(
									'id' => 'mts_related_postsnum',
									'type' => 'text',
									'class' => 'small-text',
									'title' => __('Number of related posts', 'lifestyle' ) ,
									'sub_desc' => __('Enter the number of posts to show in the related posts section.', 'lifestyle' ) ,
									'std' => '6',
									'args' => array(
										'type' => 'number'
									)
								),

							)
						),
						'author'   => array(
							'label' 	=> __('Author Box', 'lifestyle' ),
							'subfields'	=> array(

							)
						),
					),
					'disabled' => array(
						'tags'   => array(
							'label' 	=> __('Tags', 'lifestyle' ),
							'subfields'	=> array(
							)
						),
					)
				)
			),
			array(
				'id'	 => 'mts_single_headline_meta_info',
				'type'	 => 'layout',
				'title'	=> __('Meta Info to Show', 'lifestyle' ),
				'sub_desc' => __('Organize how you want the post meta info to appear', 'lifestyle' ),
				'options'  => array(
					'enabled'  => array(
						'date' => __('Date', 'lifestyle' ),
						'author' => __('Author Name', 'lifestyle' ),
					),
					'disabled' => array(
						'category' => __('Categories', 'lifestyle' ),
						'comment'  => __('Comment Count', 'lifestyle' )
					)
				),
				'std'  => array(
					'enabled'  => array(
						'date' => __('Date', 'lifestyle' ),
						'author'   => __('Author Name', 'lifestyle' ),
					),
					'disabled' => array(
						'category' => __('Categories', 'lifestyle' ),
						'comment'  => __('Comment Count', 'lifestyle' )
					)
				)
			),
			array(
				'id' => 'mts_breadcrumb',
				'type' => 'button_set',
				'title' => __('Breadcrumbs', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'lifestyle' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_show_featured',
				'type' => 'button_set',
				'title' => __('Show Featured image', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Enable/Disable the Featured images in the single post.', 'lifestyle' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_author_comment',
				'type' => 'button_set',
				'title' => __('Highlight Author Comment', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Use this button to highlight author comments.', 'lifestyle' ),
				'std' => '1'
			),
			array(
				'id' => 'mts_comment_date',
				'type' => 'button_set',
				'title' => __('Date in Comments', 'lifestyle' ),
				'options' => array( '0' => __( 'Off', 'lifestyle' ), '1' => __( 'On', 'lifestyle' ) ),
				'sub_desc' => __('Use this button to show the date for comments.', 'lifestyle' ),
				'std' => '1'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-group',
		'title' => __('Social Buttons', 'lifestyle' ),
		'desc' => '<p class="description">' . __('Enable or disable social sharing buttons on single posts using these buttons.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_social_button_layout',
				'type' => 'radio_img',
				'title' => __('Social Sharing Buttons Layout', 'MTSTHEMENAME' ),
				'sub_desc' => wp_kses( __('Choose default <strong>social sharing buttons</strong> layout or modern <strong>social sharing buttons</strong> layout for your site. ', 'MTSTHEMENAME' ), array( 'strong' => array() ) ),
				'options' => array(
					'default' => array('img' => NHP_OPTIONS_URL.'img/layouts/default-social.jpg'),
					'modern' => array('img' => NHP_OPTIONS_URL.'img/layouts/modern-social.jpg')
				),
				'std' => 'default',
				'reset_at_version' => '1.0.7'
			),
			array(
				'id' => 'mts_social_button_position',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons Position', 'lifestyle' ),
				'options' => array('top' => __('Above Content', 'lifestyle' ), 'bottom' => __('Below Content', 'lifestyle' ), 'floating' => __('Floating', 'lifestyle' )),
				'sub_desc' => __('Choose position for Social Sharing Buttons.', 'lifestyle' ),
				'std' => 'floating',
				'class' => 'green'
			),
			array(
				'id' => 'mts_social_buttons_on_pages',
				'type' => 'button_set',
				'title' => __('Social Sharing Buttons on Pages', 'lifestyle' ),
				'options' => array('0' => __('Off', 'lifestyle' ), '1' => __('On', 'lifestyle' )),
				'sub_desc' => __('Enable the sharing buttons for pages too, not just posts.', 'lifestyle' ),
				'std' => '0',
			),
			array(
				'id'   => 'mts_social_buttons',
				'type' => 'layout',
				'title'	=> __('Social Media Buttons', 'lifestyle' ),
				'sub_desc' => __('Organize how you want the social sharing buttons to appear on single posts', 'lifestyle' ),
				'options'  => array(
					'enabled'  => array(
						'facebookshare' => __('Facebook Share', 'lifestyle' ),
						'facebook'      => __('Facebook Like', 'lifestyle' ),
						'twitter'       => __('Twitter', 'lifestyle' ),
						'pinterest'     => __('Pinterest', 'lifestyle' ),
					),
					'disabled' => array(
						'linkedin' => __('LinkedIn', 'lifestyle' ),
						'stumble'  => __('StumbleUpon', 'lifestyle' ),
						'reddit'   => __('Reddit', 'lifestyle' ),
					)
				),
				'std'  => array(
					'enabled'  => array(
						'facebookshare' => __('Facebook Share', 'lifestyle' ),
						'facebook'      => __('Facebook Like', 'lifestyle' ),
						'twitter'       => __('Twitter', 'lifestyle' ),
						'pinterest'     => __('Pinterest', 'lifestyle' ),
					),
					'disabled' => array(
						'linkedin' => __('LinkedIn', 'lifestyle' ),
						'stumble'  => __('StumbleUpon', 'lifestyle' ),
						'reddit'   => __('Reddit', 'lifestyle' ),
					)
				),
				'reset_at_version' => '1.0.7'
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-bar-chart-o',
		'title' => __('Ad Management', 'lifestyle' ),
		'desc' => '<p class="description">' . __('Now, ad management is easy with our options panel. You can control everything from here, without using separate plugins.', 'lifestyle' ) . '</p>',
		'fields' => array(
			array(
				'id' => 'mts_posttop_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Title', 'lifestyle' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below your article title on single posts.', 'lifestyle' )
			),
			array(
				'id' => 'mts_posttop_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'lifestyle' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'lifestyle' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
			array(
				'id' => 'mts_postend_adcode',
				'type' => 'textarea',
				'title' => __('Below Post Content', 'lifestyle' ),
				'sub_desc' => __('Paste your Adsense, BSA or other ad code here to show ads below the post content on single posts.', 'lifestyle' )
			),
			array(
				'id' => 'mts_postend_adcode_time',
				'type' => 'text',
				'title' => __('Show After X Days', 'lifestyle' ),
				'sub_desc' => __('Enter the number of days after which you want to show the Below Post Title Ad. Enter 0 to disable this feature.', 'lifestyle' ),
				'validate' => 'numeric',
				'std' => '0',
				'class' => 'small-text',
				'args' => array('type' => 'number')
			),
		)
	);
	$sections[] = array(
		'icon' => 'fa fa-columns',
		'title' => __('Sidebars', 'lifestyle' ),
		'desc' => '<p class="description">' . __('Now you have full control over the sidebars. Here you can manage sidebars and select one for each section of your site, or select a custom sidebar on a per-post basis in the post editor.', 'lifestyle' ) . '<br></p>',
		'fields' => array(
			array(
				'id' => 'mts_custom_sidebars',
				'type'  => 'group', //doesn't need to be called for callback fields
				'title' => __('Custom Sidebars', 'lifestyle' ),
				'sub_desc'  => wp_kses( __('Add custom sidebars. <strong style="font-weight: 800;">You need to save the changes to use the sidebars in the dropdowns below.</strong><br />You can add content to the sidebars in Appearance &gt; Widgets.', 'lifestyle' ), array( 'strong' => array(), 'br' => '' ) ),
				'groupname' => __('Sidebar', 'lifestyle' ), // Group name
				'subfields' =>
					array(
						array(
							'id' => 'mts_custom_sidebar_name',
							'type' => 'text',
							'title' => __('Name', 'lifestyle' ),
							'sub_desc' => __('Example: Homepage Sidebar', 'lifestyle' )
						),
						array(
							'id' => 'mts_custom_sidebar_id',
							'type' => 'text',
							'title' => __('ID', 'lifestyle' ),
							'sub_desc' => __('Enter a unique ID for the sidebar. Use only alphanumeric characters, underscores (_) and dashes (-), eg. "sidebar-home"', 'lifestyle' ),
							'std' => 'sidebar-'
						),
					),
			),
			array(
				'id' => 'mts_sidebar_for_home',
				'type' => 'sidebars_select',
				'title' => __('Homepage', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the homepage.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_post',
				'type' => 'sidebars_select',
				'title' => __('Single Post', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the single posts. If a post has a custom sidebar set, it will override this.', 'lifestyle' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_page',
				'type' => 'sidebars_select',
				'title' => __('Single Page', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the single pages. If a page has a custom sidebar set, it will override this.', 'lifestyle' ),
				'args' => array('exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_archive',
				'type' => 'sidebars_select',
				'title' => __('Archive', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the archives. Specific archive sidebars will override this setting (see below).', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_category',
				'type' => 'sidebars_select',
				'title' => __('Category Archive', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the category archives.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_tag',
				'type' => 'sidebars_select',
				'title' => __('Tag Archive', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the tag archives.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_date',
				'type' => 'sidebars_select',
				'title' => __('Date Archive', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the date archives.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_author',
				'type' => 'sidebars_select',
				'title' => __('Author Archive', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the author archives.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_search',
				'type' => 'sidebars_select',
				'title' => __('Search', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the search results.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_notfound',
				'type' => 'sidebars_select',
				'title' => __('404 Error', 'lifestyle' ),
				'sub_desc' => __('Select a sidebar for the 404 Not found pages.', 'lifestyle' ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => ''
			),
			array(
				'id' => 'mts_sidebar_for_shop',
				'type' => 'sidebars_select',
				'title' => __('Shop Pages', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Select a sidebar for Shop main page and product archive pages (WooCommerce plugin must be enabled). Default is <strong>Shop Page Sidebar</strong>.', 'lifestyle' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'shop-sidebar'
			),
			array(
				'id' => 'mts_sidebar_for_product',
				'type' => 'sidebars_select',
				'title' => __('Single Product', 'lifestyle' ),
				'sub_desc' => wp_kses( __('Select a sidebar for single products (WooCommerce plugin must be enabled). Default is <strong>Single Product Sidebar</strong>.', 'lifestyle' ), array( 'strong' => array() ) ),
				'args' => array('allow_nosidebar' => false, 'exclude' => array('sidebar', 'footer-first', 'footer-first-2', 'footer-first-3', 'footer-first-4', 'footer-second', 'footer-second-2', 'footer-second-3', 'footer-second-4', 'widget-header','shop-sidebar', 'product-sidebar')),
				'std' => 'product-sidebar'
			),
		),
	);

	$sections[] = array(
		'icon' => 'fa fa-list-alt',
		'title' => __('Navigation', 'lifestyle' ),
		'desc' => '<p class="description"><div class="controls">' . sprintf( __('Navigation settings can now be modified from the %s.', 'lifestyle' ), '<a href="nav-menus.php"><b>' . __( 'Menus Section', 'lifestyle' ) . '</b></a>' ) . '<br></div></p>'
	);


	$tabs = array();

	$args['presets'] = array();
	$args['show_translate'] = false;
	include('theme-presets.php');

	global $NHP_Options;
	$NHP_Options = new NHP_Options($sections, $args, $tabs);

} //function

add_action('init', 'setup_framework_options', 0);

/*
 *
 * Custom function for the callback referenced above
 *
 */
function my_custom_field($field, $value){
	print_r($field);
	print_r($value);

}//function

/*
 *
 * Custom function for the callback validation referenced above
 *
 */
function validate_callback_function($field, $value, $existing_value){

	$error = false;
	$value =  'just testing';
	$return['value'] = $value;
	if($error == true){
		$return['error'] = $field;
	}
	return $return;

}//function

/*--------------------------------------------------------------------
 *
 * Default Font Settings
 *
 --------------------------------------------------------------------*/
if(function_exists('mts_register_typography')) {
	mts_register_typography( array(
		'logo_font' => array(
			'preview_text' => __( 'Logo Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_variant' => '600',
			'font_size' => '40px',
			'font_color' => '#d87ca1',
			'additional_css' => 'text-transform: uppercase; letter-spacing: 5px;',
			'css_selectors' => '#logo a'
		),
		'navigation_font' => array(
			'preview_text' => __( 'Navigation Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_variant' => 'normal',
			'font_size' => '17px',
			'font_color' => '#333333',
			'additional_css' => 'text-transform: uppercase;',
			'css_selectors' => '#primary-navigation a'
		),
		'home_title_font' => array(
			'preview_text' => __( 'Home Article Title', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_size' => '24px',
			'font_variant' => 'normal',
			'font_color' => '#333333',
			'css_selectors' => '.latestPost .title a'
		),
		'single_title_font' => array(
			'preview_text' => __( 'Single Article Title', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_size' => '27px',
			'font_variant' => 'normal',
			'font_color' => '#333333',
			'css_selectors' => '.single-title'
		),
		'content_font' => array(
			'preview_text' => __( 'Content Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_size' => '18px',
			'font_variant' => 'normal',
			'font_color' => '#424242',
			'css_selectors' => 'body'
		),
		'related_posts_font' => array(
			'preview_text' => __( 'Related Posts', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_size' => '16px',
			'font_variant' => 'normal',
			'font_color' => '#636363',
			'css_selectors' => '.related-posts .latestPost .title a'
		),
		'single_subtitle_font' => array(
			'preview_text' => __( 'Single SubTitles', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_size' => '24px',
			'font_variant' => 'bold',
			'font_color' => '#424242',
			'css_selectors' => '.related-posts h4, #respond h4, .total-comments'
		),
		'sidebar_title_font' => array(
			'preview_text' => __( 'Sidebar Title Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'bold',
			'font_size' => '21px',
			'font_color' => '#000000',
			'additional_css' => 'text-transform: uppercase;',
			'css_selectors' => '.widget h3'
		),
		'sidebar_font' => array(
			'preview_text' => __( 'Sidebar Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_variant' => '700',
			'font_size' => '14px',
			'font_color' => '#424242',
			'css_selectors' => '.widget'
		),
		'footer_title_font' => array(
			'preview_text' => __( 'Footer Title Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '18px',
			'font_color' => '#000000',
			'additional_css' => 'text-transform: uppercase;',
			'css_selectors' => '.footer-widgets h3'
		),
		'footer_font' => array(
			'preview_text' => __( 'Footer Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#444444',
			'css_selectors' => '#site-footer li, #site-footer a, #site-footer p'
		),
		'copyrights_font' => array(
			'preview_text' => __( 'Copyrights Font', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Poppins',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#333333',
			'css_selectors' => '.copyrights, .copyrights a'
		),
		'h1_headline' => array(
			'preview_text' => __( 'Content H1', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '28px',
			'font_color' => '#333333',
			'css_selectors' => 'h1'
		),
		'h2_headline' => array(
			'preview_text' => __( 'Content H2', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '24px',
			'font_color' => '#333333',
			'css_selectors' => 'h2'
		),
		'h3_headline' => array(
			'preview_text' => __( 'Content H3', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '22px',
			'font_color' => '#333333',
			'css_selectors' => 'h3'
		),
		'h4_headline' => array(
			'preview_text' => __( 'Content H4', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '20px',
			'font_color' => '#333333',
			'css_selectors' => 'h4'
		),
		'h5_headline' => array(
			'preview_text' => __( 'Content H5', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '18px',
			'font_color' => '#333333',
			'css_selectors' => 'h5'
		),
		'h6_headline' => array(
			'preview_text' => __( 'Content H6', 'lifestyle' ),
			'preview_color' => 'light',
			'font_family' => 'Arbutus Slab',
			'font_variant' => 'normal',
			'font_size' => '16px',
			'font_color' => '#333333',
			'css_selectors' => 'h6'
		)
	));
}
